<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Fechar (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Minimizar</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandir</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Descartar o alerta</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% de %Ln minuto</numerusform>
            <numerusform>%1% de %Ln minutos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% de %Ln palavra</numerusform>
            <numerusform>%1% de %Ln palavras</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln palavra</numerusform>
            <numerusform>%Ln palavras</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuto</numerusform>
            <numerusform>%Ln minutos</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Progresso diário</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Série mais longa</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Série atual</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dia</numerusform>
            <numerusform>%n dias</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>%1% do objetivo diário</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Definir língua</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sem título %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Ler apenas)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Não foi possível guardar «%1».</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Não foi possível substituir «%1».</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Alterar o nome do ficheiro</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Não foi possível alterar o nome « %1 ».</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Carregar de novo o ficheiro?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Carregar de novo o ficheiro &apos;%1&apos; do disco?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Todas as alterações não guardadas serão perdidas.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Carregar de novo</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sem título %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Guardar como texto simples descartará toda a formatação. Descartar a formatação?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Ficheiro alterado</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>O ficheiro &apos;%1&apos; foi alterado por outro programa</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Carregar de novo o ficheiro?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Carregar de novo</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Ficheiro eliminado</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>O ficheiro %1 foi eliminado por outro programa.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Gravar ou fechar o ficheiro?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Não foi possível abrir o arquivo.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Procurar por:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Substituir por:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignorar maiúsculas</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Palavras inteiras apenas</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Expressões regulares</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Para trás</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Para diante</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Procurar</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Substituir</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Substituir &amp;tudo</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Substituir</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Substituir %n ocorrência?</numerusform>
            <numerusform>Substituir %n ocorrências?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>A frase não foi encontrada.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Plain Text</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Todos os ficheiros</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Todos os ficheiros suportados</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Verificação ortográfica...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Nenhuma sugestão encontrada)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagem</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Imagens(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecionar a língua do programa:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Língua do sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie o programa para a mudança da língua do programa ser aplicada.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Não foi possível abrir o arquivo</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estatísticas</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de ferramentas</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Verificação ortográfica</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Selecionar o dicionário</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Não foi possível abrir o arquivo.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>O arquivo não contem nenhum dicionário utilizável.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Pelo menos um dos atalho está em conflito. Continuar?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>O dicionário &quot;%1&quot; já existe. Deseja substituí-lo?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Objetivo diário</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minutos:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Palavras:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Edição</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Centrar sempre na vertical</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Cursor de bloco</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Tipos de letra suavizados</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Ruídos de máquina de escrever</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Aspas curvas e angulares:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Duplas</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Cenas</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Divisor:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Gravando</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Memorizar a posição do cursor</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Número de palavras</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Número de páginas</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Número de parágrafos</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Número de caracteres</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Caracteres:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Parágrafos:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritmo de contagem de palavras</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Repor o progresso diário a zero?</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Incluir &quot;byte order mark&quot; em ficheiros &quot;plain text&quot;?</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Formato padrão:</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Repor hoje</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Lembrar histórico</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Mostrar séries</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Progresso mínimo para série:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Detetar o fim das palavras</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Dividir o número de caracteres por seis</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Contar cada letra como palavra</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritmo de contagem das páginas</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Apenas o ícone</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Apenas o texto</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Texto ao lado do ícone</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Texto por baixo do ícone</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Posição do texto:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Ações</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Subir</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Descer</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Adicionar um separador</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Verificar ortografia ao escrever</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignorar palavras em MAIÚSCULAS</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignorar palavras com números</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Língua</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Dicionário definido pelo utilizador</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Não é um ficheiro RTF suportado.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Final do ficheiro atingido inesperadamente.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Seta Abaixo</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Deslocar cenas para cima</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Seta Acima</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Comutar a lista de cenas</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Mostrar a lista de cenas (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Esconder a lista de cenas (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtrar</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Deslocar cenas para baixo</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Alterar o tamanho da lista</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Organizar as sessões</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;essões</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Alterar o nome</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Abrir a sessão</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova sessão</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duplicar sessão</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Alterar o nome da sessão</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Apagar a sessão selecionada ?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Nome da sessão:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>O nome introduzido já está a ser utilizado.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nova...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Gerir...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Repor os valores padrão</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Atalho:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>A substituir as aspas...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Espere por favor</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Verificação da ortografia</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorar</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnorar tudo</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Alterar</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>A&amp;lterar tudo</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Não consta do dicionário:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Alterar por:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Verificação da ortografia...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anular</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Espere por favor</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Continuar verificação do início do ficheiro?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Verificação da ortografia concluída.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Símbolo</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Símbolos utilizados recentemente</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Todos os símbolos</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Inserir</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blocos</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Guiões</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Sem título %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Sem imagem</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Em mosaico</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrado</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Esticada</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Ampliada</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Ampliada e cortada</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacidade:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Posição:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Fundo do texto com cantos arredondados</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Raio:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Desfocar fundo do texto</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Sombra projetada pelo fundo do texto</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Desfasamento vertical:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Margens</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Janela:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Página:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Indentar primeira linha</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Por cima:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Por baixo:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Editar tema</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Fundo da janela</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Imagem:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> píxeis</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Fundo do texto</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Tipo de letra:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Erros:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Espaço entre linhas</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 Linhas</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Duplo</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcional</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Espaçamento do parágrafo</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Largura de tabulação:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Novo tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Gentle Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Old School</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Space Dreams</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Escrivaninha</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Eliminar tema &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Temas (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importar um tema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Exportar o tema</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Eliminar cronómetro ?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Palavras :&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Páginas :&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Parágrafos :&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Caracteres :&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Ajustar a duração</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Acertar a hora</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Tempo de espera:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Hora:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Nota :</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Alterar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Nenhum cronómetro acionado</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Cronómetros</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Recente</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Cancelar a edição dos cronómetros ?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Carregamento dos temas</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Carregamento dos efeitos sonoros</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir um ficheiro</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Acerca do FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Um processador de texto simples em ecrã completo</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Disponibilizado sob licença &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Usa ícones do tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Usado sob licença &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Caracteres: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Páginas: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Parágrafos: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Palávras: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>A abrir %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sem título %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Listar todos os documentos</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Passar ao documento seguinte</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Passar ao documento anterior</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Passar ao primeiro documento</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Passar ao último documento</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Passar ao dicumento %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>A carregar definições</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Não é possível escrever na cache de emergência.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Atenção</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter não encerrou corretamente.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Recuperar dados da cache de emergência?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Alguns ficheiros não puderam ser abertos.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Alguns ficheiros foram abertos em modo de leitura.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; é mais recente do que a cópia presente na cache.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Sobrepor o ficheiro mais recente?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Guardar alterações?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Guardar alterações ao ficheiro &apos;%1&apos; antes de encerrar?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>As alterações serão perdidas se não forem guardadas.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Não foi possível carregar os ruídos de máquina de escrever.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Carrega&amp;r de novo</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Guardar &amp;como...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Mudar o nome...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Guardar t&amp;udo</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Organizar as sessões</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova sessão</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Imprimir...</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Anular</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Corta&amp;r</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Colar</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Colar &amp;sem formatação</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Seleccionar &amp;tudo</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Seleccionar &amp;cena</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmato</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Cabeçalho</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Cabeçalho &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Cabeçalho &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Cabeçalho &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Cabeçalho &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Cabeçalho &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Cabeçalho &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Negrito</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Itálico</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Sublinhar</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Ra&amp;surar</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Ex&amp;poente</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Índice</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Alinhar à &amp;esquerda</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Alinhar ao &amp;centro</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Alinhar à &amp;direita</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Justificado</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Reduzir a indentação</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>A&amp;umentar a indentação</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>&amp;Bloco de escrita da esquerda para a direita</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>B&amp;loco de escrita da direita para a esquerda</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Ferramentas</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Procurar...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Procurar se&amp;guinte</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Procurar &amp;anterior</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Substituir...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Aspas curvas e angulares</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Actualizar &amp;documento</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Actualizar a &amp;selecção</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Ortografia...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Definir &amp;língua</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>C&amp;ronómetros...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Sí&amp;mbolos...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Progresso diário</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuração</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Mostrar a &amp;barra de ferramentas</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>&amp;Mostrar os ícones no menu</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Texto f&amp;ocado</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Ecrã completo</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimizar</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Temas...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Definições...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Desligar o foco</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Focar uma linha</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Focar três linhas</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Parágrafo</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Focar parágrafo</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Língua do programa...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Alguns ficheiros não são suportados e não puderam ser abertos</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Desligado</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Uma l&amp;inha</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Três linhas</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
</context>
</TS>
